@@ -13,6 +13,12 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from oslo_config import cfg
+
+from ironic.common import release_mappings
+
+CONF = cfg.CONF
+
 # This is the version 1 API
 BASE_VERSION = 1
 
@@ -66,6 +72,7 @@ BASE_VERSION = 1
 # v1.33: Add node storage interface
 # v1.34: Add physical network field to port.
 # v1.35: Add ability to provide configdrive when rebuilding node.
+# v1.36: Add Ironic Python Agent version support.
 
 MINOR_0_JUNO = 0
 MINOR_1_INITIAL_VERSION = 1
@@ -103,12 +110,35 @@ MINOR_32_VOLUME = 32
 MINOR_33_STORAGE_INTERFACE = 33
 MINOR_34_PORT_PHYSICAL_NETWORK = 34
 MINOR_35_REBUILD_CONFIG_DRIVE = 35
+MINOR_36_AGENT_VERSION_HEARTBEAT = 36
 
-# When adding another version, update MINOR_MAX_VERSION and also update
-# doc/source/dev/webapi-version-history.rst with a detailed explanation of
-# what the version has changed.
-MINOR_MAX_VERSION = MINOR_35_REBUILD_CONFIG_DRIVE
+# When adding another version, update:
+# - MINOR_MAX_VERSION
+# - doc/source/contributor/webapi-version-history.rst with a detailed
+#   explanation of what changed in the new version
+# - common/release_mappings.py, RELEASE_MAPPING['master']['api']
+
+MINOR_MAX_VERSION = MINOR_36_AGENT_VERSION_HEARTBEAT
 
 # String representations of the minor and maximum versions
-MIN_VERSION_STRING = '{}.{}'.format(BASE_VERSION, MINOR_1_INITIAL_VERSION)
-MAX_VERSION_STRING = '{}.{}'.format(BASE_VERSION, MINOR_MAX_VERSION)
+_MIN_VERSION_STRING = '{}.{}'.format(BASE_VERSION, MINOR_1_INITIAL_VERSION)
+_MAX_VERSION_STRING = '{}.{}'.format(BASE_VERSION, MINOR_MAX_VERSION)
+
+
+def min_version_string():
+    """Returns the minimum supported API version (as a string)"""
+    return _MIN_VERSION_STRING
+
+
+def max_version_string():
+    """Returns the maximum supported API version (as a string).
+
+    If the service is pinned, the maximum API version is the pinned
+    version. Otherwise, it is the maximum supported API version.
+    """
+    release_ver = release_mappings.RELEASE_MAPPING.get(
+        CONF.pin_release_version)
+    if release_ver:
+        return release_ver['api']
+    else:
+        return _MAX_VERSION_STRING
