@@ -487,7 +487,7 @@ class UnsupportedDriverExtension(Invalid):
 
 
 class GlanceConnectionFailed(IronicException):
-    _msg_fmt = _("Connection to glance host %(endpoint)s failed: "
+    _msg_fmt = _("Connection to glance endpoint %(endpoint)s failed: "
                  "%(reason)s")
 
 
@@ -753,3 +753,12 @@ class PortgroupPhysnetInconsistent(IronicException):
 class VifInvalidForAttach(Conflict):
     _msg_fmt = _("Unable to attach VIF %(vif)s to node %(node)s. Reason: "
                  "%(reason)s")
+
+
+class AgentAPIError(IronicException):
+    _msg_fmt = _('Agent API for node %(node)s returned HTTP status code '
+                 '%(status)s with error: %(error)s')
+
+
+class NodeTraitNotFound(IronicException):
+    _msg_fmt = _("Node %(node_id)s doesn't have a trait '%(trait)s'")
