@@ -26,6 +26,7 @@
 
 # NOTE(xek): The format of this dict is:
 # { '<release version>': {
+#       'api': '<Bare Metal API version>',
 #       'rpc': '<RPC API version>',
 #       'objects':  {
 #            '<object class name>': ['<object version>'],
@@ -55,6 +56,7 @@
 
 RELEASE_MAPPING = {
     '8.0': {
+        'api': '1.31',
         'rpc': '1.40',
         'objects': {
             'Node': ['1.21'],
@@ -67,6 +69,7 @@ RELEASE_MAPPING = {
         }
     },
     '9.0': {
+        'api': '1.34',
         'rpc': '1.41',
         'objects': {
             'Node': ['1.21'],
@@ -79,6 +82,7 @@ RELEASE_MAPPING = {
         }
     },
     '9.1': {
+        'api': '1.34',
         'rpc': '1.41',
         'objects': {
             'Node': ['1.21'],
@@ -90,8 +94,9 @@ RELEASE_MAPPING = {
             'VolumeTarget': ['1.0'],
         }
     },
-    'master': {
+    '9.2': {
         'rpc': '1.41',
+        'api': '1.35',
         'objects': {
             'Node': ['1.21'],
             'Conductor': ['1.2'],
@@ -102,6 +107,32 @@ RELEASE_MAPPING = {
             'VolumeTarget': ['1.0'],
         }
     },
+    '10.0': {
+        'api': '1.36',
+        'rpc': '1.42',
+        'objects': {
+            'Node': ['1.22'],
+            'Conductor': ['1.2'],
+            'Chassis': ['1.3'],
+            'Port': ['1.7'],
+            'Portgroup': ['1.3'],
+            'VolumeConnector': ['1.0'],
+            'VolumeTarget': ['1.0'],
+        }
+    },
+    'master': {
+        'api': '1.36',
+        'rpc': '1.42',
+        'objects': {
+            'Node': ['1.22'],
+            'Conductor': ['1.2'],
+            'Chassis': ['1.3'],
+            'Port': ['1.7'],
+            'Portgroup': ['1.3'],
+            'VolumeConnector': ['1.0'],
+            'VolumeTarget': ['1.0'],
+        }
+    },
 }
 
 # NOTE(xek): Assign each named release to the appropriate semver.
