@@ -52,6 +52,18 @@ _DEFAULT_IFACE_HELP = _('Default {0} interface to be used for nodes that '
                         'be found by enumerating the '
                         '"ironic.hardware.interfaces.{0}" entrypoint.')
 
+# TODO(stendulker) Remove this in rescue API patch.
+_ENABLED_IFACE_HELP_FOR_RESCUE = (_ENABLED_IFACE_HELP +
+                                  _(' This option is part of rescue feature '
+                                    'work, which is not currently exposed to '
+                                    'users.'))
+
+# TODO(stendulker) Remove this in rescue API patch.
+_DEFAULT_IFACE_HELP_FOR_RESCUE = (_DEFAULT_IFACE_HELP +
+                                  _(' This option is part of rescue feature '
+                                    'work, which is not currently exposed to '
+                                    'users.'))
+
 api_opts = [
     cfg.StrOpt(
         'auth_strategy',
@@ -69,6 +81,9 @@ api_opts = [
                 default=False,
                 help=_('Enable pecan debug mode. WARNING: this is insecure '
                        'and should not be used in a production environment.')),
+    cfg.StrOpt('default_resource_class',
+               help=_('Resource class to use for new nodes when no resource '
+                      'class is provided in the creation request.')),
 ]
 
 driver_opts = [
@@ -134,6 +149,11 @@ driver_opts = [
                 help=_ENABLED_IFACE_HELP.format('raid')),
     cfg.StrOpt('default_raid_interface',
                help=_DEFAULT_IFACE_HELP.format('raid')),
+    cfg.ListOpt('enabled_rescue_interfaces',
+                default=['no-rescue'],
+                help=_ENABLED_IFACE_HELP_FOR_RESCUE.format('rescue')),
+    cfg.StrOpt('default_rescue_interface',
+               help=_DEFAULT_IFACE_HELP_FOR_RESCUE.format('rescue')),
     cfg.ListOpt('enabled_storage_interfaces',
                 default=['cinder', 'noop'],
                 help=_ENABLED_IFACE_HELP.format('storage')),
@@ -272,13 +292,13 @@ service_opts = [
                choices=versions.RELEASE_VERSIONS,
                # TODO(xek): mutable=True,
                help=_('Used for rolling upgrades. Setting this option '
-                      'downgrades (or pins) the internal ironic RPC '
-                      'communication and database objects to their respective '
+                      'downgrades (or pins) the Bare Metal API, '
+                      'the internal ironic RPC communication, and '
+                      'the database objects to their respective '
                       'versions, so they are compatible with older services. '
                       'When doing a rolling upgrade from version N to version '
                       'N+1, set (to pin) this to N. To unpin (default), leave '
-                      'it unset and the latest versions of RPC communication '
-                      'and database objects will be used.')),
+                      'it unset and the latest versions will be used.')),
 ]
 
 utils_opts = [
