@@ -203,10 +203,18 @@ def _get_completed_cleaning_command(task, commands):
 
 
 @METRICS.timer('log_and_raise_deployment_error')
-def log_and_raise_deployment_error(task, msg):
-    """Helper method to log the error and raise exception."""
+def log_and_raise_deployment_error(task, msg, collect_logs=True):
+    """Helper method to log the error and raise exception.
+
+    :param task: a TaskManager instance containing the node to act on.
+    :param msg: the message to set in last_error of the node.
+    :param collect_logs: Boolean indicating whether to attempt to collect
+                         logs from IPA-based ramdisk. Defaults to True.
+                         Actual log collection is also affected by
+                         CONF.agent.deploy_logs_collect config option.
+    """
     LOG.error(msg)
-    deploy_utils.set_failed_state(task, msg)
+    deploy_utils.set_failed_state(task, msg, collect_logs=collect_logs)
     raise exception.InstanceDeployFailure(msg)
 
 
@@ -264,11 +272,12 @@ class HeartbeatMixin(object):
         return (states.DEPLOYWAIT, states.CLEANWAIT)
 
     @METRICS.timer('HeartbeatMixin.heartbeat')
-    def heartbeat(self, task, callback_url):
+    def heartbeat(self, task, callback_url, agent_version):
         """Process a heartbeat.
 
         :param task: task to work with.
         :param callback_url: agent HTTP API URL.
+        :param agent_version: The version of the agent that is heartbeating
         """
         # NOTE(pas-ha) immediately skip the rest if nothing to do
         if task.node.provision_state not in self.heartbeat_allowed_states:
@@ -285,6 +294,7 @@ class HeartbeatMixin(object):
 
         driver_internal_info = node.driver_internal_info
         driver_internal_info['agent_url'] = callback_url
+        driver_internal_info['agent_version'] = agent_version
         node.driver_internal_info = driver_internal_info
         node.save()
 
@@ -590,7 +600,13 @@ class AgentDeployMixin(HeartbeatMixin):
                         {'node': node.uuid, 'error': error})
 
                 manager_utils.node_power_action(task, states.POWER_OFF)
+        except Exception as e:
+            msg = (_('Error rebooting node %(node)s after deploy. '
+                     'Error: %(error)s') %
+                   {'node': node.uuid, 'error': e})
+            log_and_raise_deployment_error(task, msg)
 
+        try:
             task.driver.network.remove_provisioning_network(task)
             task.driver.network.configure_tenant_networks(task)
 
@@ -599,7 +615,9 @@ class AgentDeployMixin(HeartbeatMixin):
             msg = (_('Error rebooting node %(node)s after deploy. '
                      'Error: %(error)s') %
                    {'node': node.uuid, 'error': e})
-            log_and_raise_deployment_error(task, msg)
+            # NOTE(mgoddard): Don't collect logs since the node has been
+            # powered off.
+            log_and_raise_deployment_error(task, msg, collect_logs=False)
 
         task.process_event('done')
         LOG.info('Deployment to node %s done', task.node.uuid)
