@@ -16,6 +16,7 @@ from ironic_lib import metrics_utils
 from oslo_log import log
 from oslo_serialization import jsonutils
 import requests
+from six.moves import http_client
 
 from ironic.common import exception
 from ironic.common.i18n import _
@@ -90,6 +91,16 @@ class AgentClient(object):
                    'res': result.get('command_result'),
                    'error': result.get('command_error'),
                    'code': response.status_code})
+
+        if response.status_code >= http_client.BAD_REQUEST:
+            LOG.error('Agent command %(method)s for node %(node)s failed. '
+                      'Expected 2xx HTTP status code, got %(code)d.',
+                      {'method': method, 'node': node.uuid,
+                       'code': response.status_code})
+            raise exception.AgentAPIError(node=node.uuid,
+                                          status=response.status_code,
+                                          error=result.get('faultstring'))
+
         return result
 
     @METRICS.timer('AgentClient.get_commands_status')
@@ -159,7 +170,7 @@ class AgentClient(object):
     @METRICS.timer('AgentClient.get_clean_steps')
     def get_clean_steps(self, node, ports):
         params = {
-            'node': node.as_dict(secure=True),
+            'node': node.as_dict(),
             'ports': [port.as_dict() for port in ports]
         }
         return self._command(node=node,
@@ -171,7 +182,7 @@ class AgentClient(object):
     def execute_clean_step(self, step, node, ports):
         params = {
             'step': step,
-            'node': node.as_dict(secure=True),
+            'node': node.as_dict(),
             'ports': [port.as_dict() for port in ports],
             'clean_version': node.driver_internal_info.get(
                 'hardware_manager_version')
