@@ -16,6 +16,7 @@
 iLO Power Driver
 """
 
+from ironic_lib import metrics_utils
 from oslo_log import log as logging
 from oslo_service import loopingcall
 from oslo_utils import importutils
@@ -23,7 +24,6 @@ from oslo_utils import importutils
 from ironic.common import boot_devices
 from ironic.common import exception
 from ironic.common.i18n import _
-from ironic.common.i18n import _LE
 from ironic.common import states
 from ironic.conductor import task_manager
 from ironic.conductor import utils as manager_utils
@@ -35,6 +35,8 @@ ilo_error = importutils.try_import('proliantutils.exception')
 
 LOG = logging.getLogger(__name__)
 
+METRICS = metrics_utils.get_metrics_logger(__name__)
+
 
 def _attach_boot_iso_if_needed(task):
     """Attaches boot ISO for a deployed node.
@@ -77,8 +79,8 @@ def _get_power_state(node):
         power_status = ilo_object.get_host_power_status()
 
     except ilo_error.IloError as ilo_exception:
-        LOG.error(_LE("iLO get_power_state failed for node %(node_id)s with "
-                      "error: %(error)s."),
+        LOG.error("iLO get_power_state failed for node %(node_id)s with "
+                  "error: %(error)s.",
                   {'node_id': node.uuid, 'error': ilo_exception})
         operation = _('iLO get_power_status')
         raise exception.IloOperationError(operation=operation,
@@ -149,8 +151,8 @@ def _set_power_state(task, target_state):
             raise exception.InvalidParameterValue(msg)
 
     except ilo_error.IloError as ilo_exception:
-        LOG.error(_LE("iLO set_power_state failed to set state to %(tstate)s "
-                      " for node %(node_id)s with error: %(error)s"),
+        LOG.error("iLO set_power_state failed to set state to %(tstate)s "
+                  " for node %(node_id)s with error: %(error)s",
                   {'tstate': target_state, 'node_id': node.uuid,
                    'error': ilo_exception})
         operation = _('iLO set_power_state')
@@ -162,8 +164,8 @@ def _set_power_state(task, target_state):
 
     if state != target_state:
         timeout = (CONF.ilo.power_wait) * (CONF.ilo.power_retry)
-        LOG.error(_LE("iLO failed to change state to %(tstate)s "
-                      "within %(timeout)s sec"),
+        LOG.error("iLO failed to change state to %(tstate)s "
+                  "within %(timeout)s sec",
                   {'tstate': target_state, 'timeout': timeout})
         raise exception.PowerStateFailure(pstate=target_state)
 
@@ -173,6 +175,7 @@ class IloPower(base.PowerInterface):
     def get_properties(self):
         return ilo_common.COMMON_PROPERTIES
 
+    @METRICS.timer('IloPower.validate')
     def validate(self, task):
         """Check if node.driver_info contains the required iLO credentials.
 
@@ -182,6 +185,7 @@ class IloPower(base.PowerInterface):
         """
         ilo_common.parse_driver_info(task.node)
 
+    @METRICS.timer('IloPower.get_power_state')
     def get_power_state(self, task):
         """Gets the current power state.
 
@@ -194,6 +198,7 @@ class IloPower(base.PowerInterface):
         """
         return _get_power_state(task.node)
 
+    @METRICS.timer('IloPower.set_power_state')
     @task_manager.require_exclusive_lock
     def set_power_state(self, task, power_state):
         """Turn the current power state on or off.
@@ -208,6 +213,7 @@ class IloPower(base.PowerInterface):
         """
         _set_power_state(task, power_state)
 
+    @METRICS.timer('IloPower.reboot')
     @task_manager.require_exclusive_lock
     def reboot(self, task):
         """Reboot the node
