@@ -57,8 +57,8 @@ class NeutronNetwork(common.NeutronVIFPortIDMixin,
             is invalid.
         :raises: MissingParameterValue, if some parameters are missing.
         """
-        self.get_cleaning_network_uuid()
-        self.get_provisioning_network_uuid()
+        self.get_cleaning_network_uuid(context=task.context)
+        self.get_provisioning_network_uuid(context=task.context)
 
     def add_provisioning_network(self, task):
         """Add the provisioning network to a node.
@@ -68,11 +68,12 @@ class NeutronNetwork(common.NeutronVIFPortIDMixin,
         """
         # If we have left over ports from a previous provision attempt, remove
         # them
-        neutron.rollback_ports(task, self.get_provisioning_network_uuid())
+        neutron.rollback_ports(
+            task, self.get_provisioning_network_uuid(context=task.context))
         LOG.info('Adding provisioning network to node %s',
                  task.node.uuid)
         vifs = neutron.add_ports_to_network(
-            task, self.get_provisioning_network_uuid(),
+            task, self.get_provisioning_network_uuid(context=task.context),
             security_groups=CONF.neutron.provisioning_network_security_groups)
         for port in task.ports:
             if port.uuid in vifs:
@@ -90,7 +91,7 @@ class NeutronNetwork(common.NeutronVIFPortIDMixin,
         LOG.info('Removing provisioning network from node %s',
                  task.node.uuid)
         neutron.remove_ports_from_network(
-            task, self.get_provisioning_network_uuid())
+            task, self.get_provisioning_network_uuid(context=task.context))
         for port in task.ports:
             if 'provisioning_vif_port_id' in port.internal_info:
                 internal_info = port.internal_info
@@ -106,12 +107,14 @@ class NeutronNetwork(common.NeutronVIFPortIDMixin,
         :returns: a dictionary in the form {port.uuid: neutron_port['id']}
         """
         # If we have left over ports from a previous cleaning, remove them
-        neutron.rollback_ports(task, self.get_cleaning_network_uuid())
+        neutron.rollback_ports(task, self.get_cleaning_network_uuid(
+            context=task.context))
         LOG.info('Adding cleaning network to node %s', task.node.uuid)
         security_groups = CONF.neutron.cleaning_network_security_groups
-        vifs = neutron.add_ports_to_network(task,
-                                            self.get_cleaning_network_uuid(),
-                                            security_groups=security_groups)
+        vifs = neutron.add_ports_to_network(
+            task,
+            self.get_cleaning_network_uuid(context=task.context),
+            security_groups=security_groups)
         for port in task.ports:
             if port.uuid in vifs:
                 internal_info = port.internal_info
@@ -128,8 +131,8 @@ class NeutronNetwork(common.NeutronVIFPortIDMixin,
         """
         LOG.info('Removing cleaning network from node %s',
                  task.node.uuid)
-        neutron.remove_ports_from_network(task,
-                                          self.get_cleaning_network_uuid())
+        neutron.remove_ports_from_network(
+            task, self.get_cleaning_network_uuid(context=task.context))
         for port in task.ports:
             if 'cleaning_vif_port_id' in port.internal_info:
                 internal_info = port.internal_info
@@ -158,7 +161,7 @@ class NeutronNetwork(common.NeutronVIFPortIDMixin,
         ports = [p for p in ports if not p.portgroup_id]
         portgroups = task.portgroups
 
-        client = neutron.get_client()
+        client = neutron.get_client(context=task.context)
         pobj_without_vif = 0
         for port_like_obj in ports + portgroups:
 
@@ -196,4 +199,4 @@ class NeutronNetwork(common.NeutronVIFPortIDMixin,
                 port_like_obj.extra.get('vif_port_id'))
             if not vif_port_id:
                 continue
-            neutron.unbind_neutron_port(vif_port_id)
+            neutron.unbind_neutron_port(vif_port_id, context=task.context)
