@@ -14,7 +14,7 @@
 
 import mock
 from oslo_utils import uuidutils
-from stevedore import dispatch
+from stevedore import named
 
 from ironic.common import driver_factory
 from ironic.common import exception
@@ -45,7 +45,7 @@ class DriverLoadTestCase(db_base.DbTestCase):
 
     def test_driver_load_error_if_driver_enabled(self):
         self.config(enabled_drivers=['fake'])
-        with mock.patch.object(dispatch.NameDispatchExtensionManager,
+        with mock.patch.object(named.NamedExtensionManager,
                                '__init__', self._fake_init_driver_err):
             self.assertRaises(
                 exception.DriverLoadError,
@@ -53,20 +53,20 @@ class DriverLoadTestCase(db_base.DbTestCase):
 
     def test_wrap_in_driver_load_error_if_driver_enabled(self):
         self.config(enabled_drivers=['fake'])
-        with mock.patch.object(dispatch.NameDispatchExtensionManager,
+        with mock.patch.object(named.NamedExtensionManager,
                                '__init__', self._fake_init_name_err):
             self.assertRaises(
                 exception.DriverLoadError,
                 driver_factory.DriverFactory._init_extension_manager)
 
-    @mock.patch.object(dispatch.NameDispatchExtensionManager, 'names',
+    @mock.patch.object(named.NamedExtensionManager, 'names',
                        autospec=True)
     def test_no_driver_load_error_if_driver_disabled(self, mock_em):
         self.config(enabled_drivers=[])
-        with mock.patch.object(dispatch.NameDispatchExtensionManager,
+        with mock.patch.object(named.NamedExtensionManager,
                                '__init__', self._fake_init_driver_err):
             driver_factory.DriverFactory._init_extension_manager()
-            self.assertEqual(3, mock_em.call_count)
+            self.assertEqual(1, mock_em.call_count)
 
     @mock.patch.object(driver_factory.LOG, 'warning', autospec=True)
     def test_driver_duplicated_entry(self, mock_log):
@@ -97,7 +97,10 @@ class DriverLoadTestCase(db_base.DbTestCase):
         with task_manager.acquire(self.context, node.id) as task:
             for iface in drivers_base.ALL_INTERFACES:
                 impl = getattr(task.driver, iface)
-                self.assertIsNotNone(impl)
+                if iface == 'rescue':
+                    self.assertIsNone(impl)
+                else:
+                    self.assertIsNotNone(impl)
 
     @mock.patch.object(driver_factory, '_attach_interfaces_to_driver',
                        autospec=True)
@@ -580,6 +583,11 @@ class TestFakeHardware(hardware_type.AbstractHardwareType):
         """List of supported raid interfaces."""
         return [fake.FakeRAID]
 
+    @property
+    def supported_rescue_interfaces(self):
+        """List of supported rescue interfaces."""
+        return [fake.FakeRescue]
+
     @property
     def supported_vendor_interfaces(self):
         """List of supported rescue interfaces."""
@@ -732,6 +740,25 @@ class HardwareTypeLoadTestCase(db_base.DbTestCase):
                           driver_factory.check_and_update_node_interfaces,
                           node)
 
+    def test_none_rescue_interface(self):
+        node = obj_utils.get_test_node(self.context, driver='fake')
+        self.assertTrue(driver_factory.check_and_update_node_interfaces(node))
+        self.assertIsNone(node.rescue_interface)
+
+    def test_no_rescue_interface_default_from_conf(self):
+        self.config(enabled_rescue_interfaces=['fake'])
+        self.config(default_rescue_interface='fake')
+        node = obj_utils.get_test_node(self.context, driver='fake-hardware')
+        self.assertTrue(driver_factory.check_and_update_node_interfaces(node))
+        self.assertEqual('fake', node.rescue_interface)
+
+    def test_invalid_rescue_interface(self):
+        node = obj_utils.get_test_node(self.context, driver='fake-hardware',
+                                       rescue_interface='scoop')
+        self.assertRaises(exception.InterfaceNotFoundInEntrypoint,
+                          driver_factory.check_and_update_node_interfaces,
+                          node)
+
     def test_no_raid_interface_no_default(self):
         # NOTE(rloo): It doesn't seem possible to not have a default interface
         #             for storage, so we'll test this case with raid.
@@ -753,6 +780,7 @@ class HardwareTypeLoadTestCase(db_base.DbTestCase):
             'network': set(['noop']),
             'power': set(['fake']),
             'raid': set(['fake']),
+            'rescue': set(['fake']),
             'storage': set([]),
             'vendor': set(['fake'])
         }
