@@ -62,24 +62,6 @@ LOG = logging.getLogger(__name__)
 MIGRATIONS_TIMEOUT = 300
 
 
-def _get_connect_string(backend, user, passwd, database):
-    """Get database connection
-
-    Try to get a connection with a very specific set of values, if we get
-    these then we'll run the tests, otherwise they are skipped
-    """
-    if backend == "postgres":
-        backend = "postgresql+psycopg2"
-    elif backend == "mysql":
-        backend = "mysql+mysqldb"
-    else:
-        raise Exception("Unrecognized backend: '%s'" % backend)
-
-    return ("%(backend)s://%(user)s:%(passwd)s@localhost/%(database)s"
-            % {'backend': backend, 'user': user, 'passwd': passwd,
-               'database': database})
-
-
 @contextlib.contextmanager
 def patch_with_engine(engine):
     with mock.patch.object(enginefacade.writer,
@@ -651,6 +633,38 @@ class MigrationCheckersMixin(object):
             self.assertIsInstance(table.c.version.type,
                                   sqlalchemy.types.String)
 
+    def _check_405cfe08f18d(self, engine, data):
+        nodes = db_utils.get_table(engine, 'nodes')
+        col_names = [column.name for column in nodes.c]
+        self.assertIn('rescue_interface', col_names)
+        self.assertIsInstance(nodes.c.rescue_interface.type,
+                              sqlalchemy.types.String)
+
+    def _pre_upgrade_b4130a7fc904(self, engine):
+        # Create a node to which traits can be added.
+        data = {'uuid': uuidutils.generate_uuid()}
+        nodes = db_utils.get_table(engine, 'nodes')
+        nodes.insert().execute(data)
+        node = nodes.select(nodes.c.uuid == data['uuid']).execute().first()
+        data['id'] = node['id']
+        return data
+
+    def _check_b4130a7fc904(self, engine, data):
+        node_traits = db_utils.get_table(engine, 'node_traits')
+        col_names = [column.name for column in node_traits.c]
+        self.assertIn('node_id', col_names)
+        self.assertIsInstance(node_traits.c.node_id.type,
+                              sqlalchemy.types.Integer)
+        self.assertIn('trait', col_names)
+        self.assertIsInstance(node_traits.c.trait.type,
+                              sqlalchemy.types.String)
+
+        trait = {'node_id': data['id'], 'trait': 'trait1'}
+        node_traits.insert().execute(trait)
+        trait = node_traits.select(
+            node_traits.c.node_id == data['id']).execute().first()
+        self.assertEqual('trait1', trait['trait'])
+
     def test_upgrade_and_version(self):
         with patch_with_engine(self.engine):
             self.migration_api.upgrade('head')
