@@ -38,6 +38,11 @@ class DbNodeTestCase(base.DbTestCase):
                           utils.create_test_node,
                           tags=['tag1', 'tag2'])
 
+    def test_create_node_with_traits(self):
+        self.assertRaises(exception.InvalidParameterValue,
+                          utils.create_test_node,
+                          traits=['trait1', 'trait2'])
+
     def test_create_node_already_exists(self):
         utils.create_test_node()
         self.assertRaises(exception.NodeAlreadyExists,
@@ -167,26 +172,6 @@ class DbNodeTestCase(base.DbTestCase):
         self.assertEqual(sorted([node1.id, node3.id]),
                          sorted([r.id for r in res]))
 
-        res = self.dbapi.get_node_list(filters={'id': node1.id})
-        self.assertEqual([node1.id], [r.id for r in res])
-
-        res = self.dbapi.get_node_list(filters={'uuid': node1.uuid})
-        self.assertEqual([node1.id], [r.id for r in res])
-
-        # ensure unknown filters explode
-        filters = {'bad_filter': 'foo'}
-        self.assertRaisesRegex(ValueError,
-                               'bad_filter',
-                               self.dbapi.get_node_list,
-                               filters=filters)
-
-        # even with good filters present
-        filters = {'bad_filter': 'foo', 'id': node1.id}
-        self.assertRaisesRegex(ValueError,
-                               'bad_filter',
-                               self.dbapi.get_node_list,
-                               filters=filters)
-
     @mock.patch.object(timeutils, 'utcnow', autospec=True)
     def test_get_nodeinfo_list_provision(self, mock_utcnow):
         past = datetime.datetime(2000, 1, 1, 0, 0)
@@ -419,6 +404,26 @@ class DbNodeTestCase(base.DbTestCase):
         self.assertRaises(exception.VolumeTargetNotFound,
                           self.dbapi.get_volume_target_by_id, target.id)
 
+    def test_traits_get_destroyed_after_destroying_a_node(self):
+        node = utils.create_test_node()
+
+        trait = utils.create_test_node_trait(node_id=node.id)
+
+        self.assertTrue(self.dbapi.node_trait_exists(node.id, trait.trait))
+        self.dbapi.destroy_node(node.id)
+        self.assertRaises(exception.NodeNotFound,
+                          self.dbapi.node_trait_exists, node.id, trait.trait)
+
+    def test_traits_get_destroyed_after_destroying_a_node_by_uuid(self):
+        node = utils.create_test_node()
+
+        trait = utils.create_test_node_trait(node_id=node.id)
+
+        self.assertTrue(self.dbapi.node_trait_exists(node.id, trait.trait))
+        self.dbapi.destroy_node(node.uuid)
+        self.assertRaises(exception.NodeNotFound,
+                          self.dbapi.node_trait_exists, node.id, trait.trait)
+
     def test_update_node(self):
         node = utils.create_test_node()
 
