@@ -45,7 +45,6 @@ from ironic.tests.unit.db import utils as db_utils
 from ironic.tests.unit.drivers import third_party_driver_mock_specs \
     as mock_specs
 from ironic.tests.unit.objects import utils as obj_utils
-
 if six.PY3:
     import io
     file = io.BytesIO
@@ -1075,6 +1074,139 @@ class IRMCVirtualMediaBootTestCase(db_base.DbTestCase):
         self.assertRaises(ValueError, cfg.CONF.set_override,
                           'remote_image_share_type', 'fake', 'irmc')
 
+    @mock.patch.object(irmc_common, 'set_secure_boot_mode', spec_set=True,
+                       autospec=True)
+    @mock.patch.object(irmc_boot.IRMCVirtualMediaBoot,
+                       '_configure_vmedia_boot', spec_set=True,
+                       autospec=True)
+    @mock.patch.object(irmc_boot, '_cleanup_vmedia_boot', spec_set=True,
+                       autospec=True)
+    def test_prepare_instance_with_secure_boot(self, mock_cleanup_vmedia_boot,
+                                               mock_configure_vmedia_boot,
+                                               mock_set_secure_boot_mode):
+        self.node.driver_internal_info = {'root_uuid_or_disk_id': "12312642"}
+        self.node.provision_state = states.DEPLOYING
+        self.node.target_provision_state = states.ACTIVE
+        self.node.instance_info = {
+            'capabilities': {
+                "secure_boot": "true"
+            }
+        }
+        self.node.save()
+        with task_manager.acquire(self.context, self.node.uuid,
+                                  shared=False) as task:
+            task.driver.boot.prepare_instance(task)
+            mock_cleanup_vmedia_boot.assert_called_once_with(task)
+            mock_set_secure_boot_mode.assert_called_once_with(task.node,
+                                                              enable=True)
+            mock_configure_vmedia_boot.assert_called_once_with(mock.ANY, task,
+                                                               "12312642")
+
+    @mock.patch.object(irmc_common, 'set_secure_boot_mode', spec_set=True,
+                       autospec=True)
+    @mock.patch.object(irmc_boot.IRMCVirtualMediaBoot,
+                       '_configure_vmedia_boot', spec_set=True,
+                       autospec=True)
+    @mock.patch.object(irmc_boot, '_cleanup_vmedia_boot', spec_set=True,
+                       autospec=True)
+    def test_prepare_instance_with_secure_boot_false(
+            self, mock_cleanup_vmedia_boot, mock_configure_vmedia_boot,
+            mock_set_secure_boot_mode):
+        self.node.driver_internal_info = {'root_uuid_or_disk_id': "12312642"}
+        self.node.provision_state = states.DEPLOYING
+        self.node.target_provision_state = states.ACTIVE
+        self.node.instance_info = {
+            'capabilities': {
+                "secure_boot": "false"
+            }
+        }
+        self.node.save()
+        with task_manager.acquire(self.context, self.node.uuid,
+                                  shared=False) as task:
+            task.driver.boot.prepare_instance(task)
+            mock_cleanup_vmedia_boot.assert_called_once_with(task)
+            self.assertFalse(mock_set_secure_boot_mode.called)
+            mock_configure_vmedia_boot.assert_called_once_with(mock.ANY, task,
+                                                               "12312642")
+
+    @mock.patch.object(irmc_common, 'set_secure_boot_mode', spec_set=True,
+                       autospec=True)
+    @mock.patch.object(irmc_boot.IRMCVirtualMediaBoot,
+                       '_configure_vmedia_boot', spec_set=True,
+                       autospec=True)
+    @mock.patch.object(irmc_boot, '_cleanup_vmedia_boot', spec_set=True,
+                       autospec=True)
+    def test_prepare_instance_without_secure_boot(
+            self, mock_cleanup_vmedia_boot, mock_configure_vmedia_boot,
+            mock_set_secure_boot_mode):
+        self.node.driver_internal_info = {'root_uuid_or_disk_id': "12312642"}
+        self.node.provision_state = states.DEPLOYING
+        self.node.target_provision_state = states.ACTIVE
+        self.node.save()
+        with task_manager.acquire(self.context, self.node.uuid,
+                                  shared=False) as task:
+            task.driver.boot.prepare_instance(task)
+            mock_cleanup_vmedia_boot.assert_called_once_with(task)
+            self.assertFalse(mock_set_secure_boot_mode.called)
+            mock_configure_vmedia_boot.assert_called_once_with(mock.ANY, task,
+                                                               "12312642")
+
+    @mock.patch.object(irmc_common, 'set_secure_boot_mode', spec_set=True,
+                       autospec=True)
+    @mock.patch.object(irmc_boot, '_cleanup_vmedia_boot', spec_set=True,
+                       autospec=True)
+    def test_clean_up_instance_with_secure_boot(self, mock_cleanup_vmedia_boot,
+                                                mock_set_secure_boot_mode):
+        self.node.provision_state = states.DELETING
+        self.node.target_provision_state = states.AVAILABLE
+        self.node.instance_info = {
+            'capabilities': {
+                "secure_boot": "true"
+            }
+        }
+        self.node.save()
+        with task_manager.acquire(self.context, self.node.uuid,
+                                  shared=False) as task:
+            task.driver.boot.clean_up_instance(task)
+            mock_set_secure_boot_mode.assert_called_once_with(task.node,
+                                                              enable=False)
+            mock_cleanup_vmedia_boot.assert_called_once_with(task)
+
+    @mock.patch.object(irmc_common, 'set_secure_boot_mode', spec_set=True,
+                       autospec=True)
+    @mock.patch.object(irmc_boot, '_cleanup_vmedia_boot', spec_set=True,
+                       autospec=True)
+    def test_clean_up_instance_with_secure_boot_false(
+            self, mock_cleanup_vmedia_boot, mock_set_secure_boot_mode):
+        self.node.provision_state = states.DELETING
+        self.node.target_provision_state = states.AVAILABLE
+        self.node.instance_info = {
+            'capabilities': {
+                "secure_boot": "false"
+            }
+        }
+        self.node.save()
+        with task_manager.acquire(self.context, self.node.uuid,
+                                  shared=False) as task:
+            task.driver.boot.clean_up_instance(task)
+            self.assertFalse(mock_set_secure_boot_mode.called)
+            mock_cleanup_vmedia_boot.assert_called_once_with(task)
+
+    @mock.patch.object(irmc_common, 'set_secure_boot_mode', spec_set=True,
+                       autospec=True)
+    @mock.patch.object(irmc_boot, '_cleanup_vmedia_boot', spec_set=True,
+                       autospec=True)
+    def test_clean_up_instance_without_secure_boot(
+            self, mock_cleanup_vmedia_boot, mock_set_secure_boot_mode):
+        self.node.provision_state = states.DELETING
+        self.node.target_provision_state = states.AVAILABLE
+        self.node.save()
+        with task_manager.acquire(self.context, self.node.uuid,
+                                  shared=False) as task:
+            task.driver.boot.clean_up_instance(task)
+            self.assertFalse(mock_set_secure_boot_mode.called)
+            mock_cleanup_vmedia_boot.assert_called_once_with(task)
+
 
 class IRMCPXEBootTestCase(db_base.DbTestCase):
 
