@@ -25,11 +25,10 @@ from ironic.tests import base
 
 
 class MockResponse(object):
-    status_code = http_client.OK
-
-    def __init__(self, text):
+    def __init__(self, text, status_code=http_client.OK):
         assert isinstance(text, six.string_types)
         self.text = text
+        self.status_code = status_code
 
     def json(self):
         return json.loads(self.text)
@@ -44,8 +43,7 @@ class MockNode(object):
         }
         self.instance_info = {}
 
-    def as_dict(self, secure=False):
-        assert secure, 'agent_client must pass secure=True'
+    def as_dict(self):
         return {
             'uuid': self.uuid,
             'driver_internal_info': self.driver_internal_info,
@@ -134,6 +132,25 @@ class TestAgentClient(base.TestCase):
                          {'method': method, 'node': self.node.uuid,
                           'error': error}, str(e))
 
+    def test__command_error_code(self):
+        response_text = '{"faultstring": "you dun goofd"}'
+        self.client.session.post.return_value = MockResponse(
+            response_text, status_code=http_client.BAD_REQUEST)
+        method = 'standby.run_image'
+        image_info = {'image_id': 'test_image'}
+        params = {'image_info': image_info}
+
+        url = self.client._get_command_url(self.node)
+        body = self.client._get_command_body(method, params)
+
+        self.assertRaises(exception.AgentAPIError,
+                          self.client._command,
+                          self.node, method, params)
+        self.client.session.post.assert_called_once_with(
+            url,
+            data=body,
+            params={'wait': 'false'})
+
     def test_get_commands_status(self):
         with mock.patch.object(self.client.session, 'get',
                                autospec=True) as mock_get:
@@ -228,7 +245,7 @@ class TestAgentClient(base.TestCase):
         self.client._command = mock.MagicMock(spec_set=[])
         ports = []
         expected_params = {
-            'node': self.node.as_dict(secure=True),
+            'node': self.node.as_dict(),
             'ports': []
         }
 
@@ -244,7 +261,7 @@ class TestAgentClient(base.TestCase):
         step = {'priority': 10, 'step': 'erase_devices', 'interface': 'deploy'}
         expected_params = {
             'step': step,
-            'node': self.node.as_dict(secure=True),
+            'node': self.node.as_dict(),
             'ports': [],
             'clean_version':
                 self.node.driver_internal_info['hardware_manager_version']
