@@ -117,6 +117,17 @@ class IscsiDeployMethodsTestCase(db_base.DbTestCase):
             get_image_mb_mock.assert_called_once_with(
                 iscsi_deploy._get_image_file_path(task.node.uuid))
 
+    @mock.patch.object(disk_utils, 'get_image_mb', autospec=True)
+    def test_check_image_size_whole_disk_image(self, get_image_mb_mock):
+        get_image_mb_mock.return_value = 1025
+        with task_manager.acquire(self.context, self.node.uuid,
+                                  shared=False) as task:
+            task.node.instance_info['root_gb'] = 1
+            task.node.driver_internal_info['is_whole_disk_image'] = True
+            # No error for whole disk images
+            iscsi_deploy.check_image_size(task)
+            self.assertFalse(get_image_mb_mock.called)
+
     @mock.patch.object(disk_utils, 'get_image_mb', autospec=True)
     def test_check_image_size_fails(self, get_image_mb_mock):
         get_image_mb_mock.return_value = 1025
@@ -744,12 +755,16 @@ class ISCSIDeployTestCase(db_base.DbTestCase):
 
     @mock.patch.object(noop_storage.NoopStorage, 'detach_volumes',
                        autospec=True)
+    @mock.patch.object(flat_network.FlatNetwork,
+                       'remove_provisioning_network',
+                       spec_set=True, autospec=True)
     @mock.patch.object(flat_network.FlatNetwork,
                        'unconfigure_tenant_networks',
                        spec_set=True, autospec=True)
     @mock.patch.object(manager_utils, 'node_power_action', autospec=True)
     def test_tear_down(self, node_power_action_mock,
                        unconfigure_tenant_nets_mock,
+                       remove_provisioning_net_mock,
                        storage_detach_volumes_mock):
         obj_utils.create_test_volume_target(
             self.context, node_id=self.node.id)
@@ -761,6 +776,8 @@ class ISCSIDeployTestCase(db_base.DbTestCase):
                                                            states.POWER_OFF)
             unconfigure_tenant_nets_mock.assert_called_once_with(mock.ANY,
                                                                  task)
+            remove_provisioning_net_mock.assert_called_once_with(mock.ANY,
+                                                                 task)
             storage_detach_volumes_mock.assert_called_once_with(
                 task.driver.storage, task)
         # Verify no volumes exist for new task instances.
