@@ -406,7 +406,7 @@ class TestDeployInterface(base.TestCase):
         deploy = fake.FakeDeploy()
         deploy.heartbeat(mock.Mock(node=mock.Mock(uuid='uuid',
                                                   driver='driver')),
-                         'url')
+                         'url', '3.2.0')
         self.assertTrue(mock_log.called)
 
 
@@ -447,6 +447,7 @@ class TestBareDriver(base.TestCase):
         self.assertEqual(('deploy', 'power', 'network'),
                          driver_base.BareDriver.core_interfaces)
         self.assertEqual(
-            ('boot', 'console', 'inspect', 'management', 'raid', 'storage'),
+            ('boot', 'console', 'inspect', 'management', 'raid',
+             'rescue', 'storage'),
             driver_base.BareDriver.standard_interfaces
         )
